import { AST, MediaCondition, MediaFeature, NumberToken, DimensionToken, RatioToken, IdentToken } from "media-query-parser";
export declare type ConditionRange<T = number> = [boolean, T, T, boolean];
export declare type Condition<T> = T | "{never}" | "{invalid}";
export declare type FullFeatureSet = {
    "any-hover": "none" | "hover";
    "any-pointer": "none" | "coarse" | "fine";
    "color-gamut": [
        belowSrgb: boolean,
        srgbAndBelowP3: boolean,
        p3AndBelowRec2020: boolean,
        rec2020AndAbove: boolean
    ];
    grid: 0 | 1;
    hover: "none" | "hover";
    "overflow-block": "none" | "scroll" | "paged";
    "overflow-inline": "none" | "scroll";
    pointer: "none" | "coarse" | "fine";
    scan: "interlace" | "progressive";
    update: "none" | "slow" | "fast";
    "aspect-ratio": ConditionRange<[number, number]>;
    color: ConditionRange;
    "color-index": ConditionRange;
    "device-aspect-ratio": ConditionRange<[number, number]>;
    "device-height": ConditionRange;
    "device-width": ConditionRange;
    height: ConditionRange;
    monochrome: ConditionRange;
    resolution: ConditionRange;
    width: ConditionRange;
};
export declare type FullConditionSet = {
    [Property in keyof FullFeatureSet]: Condition<FullFeatureSet[Property]>;
} & {
    "media-type": "screen" | "print" | "not-screen" | "not-print" | "all" | "{never}";
    "invalid-features": string[];
};
export declare type ConditionSet = Partial<FullConditionSet>;
export declare type ConditionSets = ConditionSet[];
export declare type StandardLengthUnit = {
    type: "dimension";
    subtype: "length";
    px: number;
};
export declare type StandardTimeUnit = {
    type: "dimension";
    subtype: "time";
    ms: number;
};
export declare type StandardFrequencyUnit = {
    type: "dimension";
    subtype: "frequency";
    hz: number;
};
export declare type StandardResolutionUnit = {
    type: "dimension";
    subtype: "resolution";
    dppx: number;
};
export declare type StandardInfiniteUnit = {
    type: "infinite";
};
export declare type StandardIdentUnit = {
    type: "ident";
    value: string;
};
export declare type StandardDimensionUnit = StandardLengthUnit | StandardTimeUnit | StandardFrequencyUnit | StandardResolutionUnit | StandardInfiniteUnit | StandardIdentUnit;
export declare type StandardNumberUnit = {
    type: "number";
    value: number;
};
export declare type StandardRatioUnit = {
    type: "ratio";
    numerator: number;
    denominator: number;
};
export declare type StandardUnit = StandardDimensionUnit | StandardNumberUnit | StandardRatioUnit;
export declare type UnitConversions = {
    widthPx: number;
    heightPx: number;
    writingMode: "horizontal-tb" | "vertical-rl" | "vertical-lr" | "sideways-rl" | "sideways-lr";
    emPx: number;
    lhPx: number;
    exPx: number;
    chPx: number;
    capPx: number;
    icPx: number;
};
export declare type CompiledUnitConversions = {
    vw: number;
    vh: number;
    vmin: number;
    vmax: number;
    vi: number;
    vb: number;
    em: number;
    rem: number;
    lh: number;
    rlh: number;
    ex: number;
    ch: number;
    cap: number;
    ic: number;
    cm: number;
    mm: number;
    in: number;
    q: number;
    pc: number;
    pt: number;
};
export declare type SimplifiedPermutation = Partial<FullFeatureSet & {
    "media-type": Exclude<FullConditionSet["media-type"], "all" | "{never}" | "{invalid}">;
}>;
export declare type EvaluateResult = {
    permutations: SimplifiedPermutation[];
    invalidFeatures: string[];
    neverFeatures: string[];
};
export declare const DISCRETE_FEATURES: {
    readonly "any-hover": {
        readonly none: 1;
        readonly hover: 1;
    };
    readonly "any-pointer": {
        readonly none: 1;
        readonly coarse: 1;
        readonly fine: 1;
    };
    readonly "color-gamut": {
        readonly srgb: 1;
        readonly p3: 1;
        readonly rec2020: 1;
    };
    readonly grid: {
        readonly 0: 1;
        readonly 1: 1;
    };
    readonly hover: {
        readonly none: 1;
        readonly hover: 1;
    };
    readonly "overflow-block": {
        readonly none: 1;
        readonly scroll: 1;
        readonly paged: 1;
    };
    readonly "overflow-inline": {
        readonly none: 1;
        readonly scroll: 1;
    };
    readonly pointer: {
        readonly none: 1;
        readonly coarse: 1;
        readonly fine: 1;
    };
    readonly scan: {
        readonly interlace: 1;
        readonly progressive: 1;
    };
    readonly update: {
        readonly none: 1;
        readonly slow: 1;
        readonly fast: 1;
    };
};
export declare const RANGE_FEATURES: {
    readonly "aspect-ratio": {
        readonly feature: "aspect-ratio";
        readonly type: "ratio";
        readonly bounds: readonly [false, readonly [0, 1], readonly [number, 1], false];
    };
    readonly "device-aspect-ratio": {
        readonly feature: "device-aspect-ratio";
        readonly type: "ratio";
        readonly bounds: readonly [false, readonly [0, 1], readonly [number, 1], false];
    };
    readonly color: {
        readonly feature: "color";
        readonly type: "integer";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly "color-index": {
        readonly feature: "color-index";
        readonly type: "integer";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly monochrome: {
        readonly feature: "monochrome";
        readonly type: "integer";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly "device-height": {
        readonly feature: "device-height";
        readonly type: "length";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly "device-width": {
        readonly feature: "device-width";
        readonly type: "length";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly height: {
        readonly feature: "height";
        readonly type: "length";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly width: {
        readonly feature: "width";
        readonly type: "length";
        readonly bounds: readonly [true, 0, number, false];
    };
    readonly resolution: {
        readonly feature: "resolution";
        readonly type: "resolution";
        readonly bounds: readonly [true, 0, number, false];
    };
};
export declare const convertToStandardUnit: (token: NumberToken | DimensionToken | RatioToken | IdentToken, unitConversions: CompiledUnitConversions) => StandardUnit;
export declare const andConditionSets: (a: ConditionSets, b: ConditionSets) => ConditionSets;
export declare const mergeConditionSets: (setA: ConditionSet, setB: ConditionSet) => ConditionSet;
export declare const notConditionSets: (conditionSets: ConditionSets) => ConditionSets;
export declare const invertConditionSet: (set: ConditionSet) => ConditionSets;
export declare const mediaFeatureToConditionSets: (mediaFeature: MediaFeature, unitConversions: CompiledUnitConversions) => ConditionSets | string;
export declare const mediaConditionToConditionSets: (mediaCondition: MediaCondition, unitConversions: CompiledUnitConversions) => ConditionSets;
export declare const simplifyConditionSets: (conditionSets: ConditionSets) => EvaluateResult;
export declare const compileAST: (ast: AST, units?: Partial<UnitConversions>) => EvaluateResult;
export declare const compileQuery: (query: string, units?: Partial<UnitConversions>) => EvaluateResult;
//# sourceMappingURL=compile.d.ts.map